package
Version:
v0.8.3
Opens a new window with list of versions in this module.
Published: Jul 15, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
var (
ErrModuleNotFound = errors.New("module not found")
ErrLicenseNotFound = errors.New("no license found")
ErrLocalModule = errors.New("license resolution isn't supported for local modules")
)
type SPDXLicense struct {
ID string `json:"licenseId"`
Name string `json:"name"`
Reference string `json:"reference"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.